@@ -4,6 +4,7 @@
 """Raspberry Pi"""
 
 import os
+import platform
 import re
 
 
@@ -15,7 +16,12 @@ MAC_ADDR_PREFIX = [
 
 
 def get_raspberry_pi():
+    cur_system = platform.system()
     command = f"""arp -na | grep -i -E '{"|".join(MAC_ADDR_PREFIX)}'"""
+
+    if "window" in cur_system.lower():
+        command = f'''arp -a | findstr -i "{' '.join(MAC_ADDR_PREFIX)}"'''
+
     res = os.popen(command).read()
     if not res:
         return
@@ -27,7 +33,10 @@ def get_raspberry_pi():
             mac = re.search(r"([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})", r).group()
         except AttributeError:
             mac = "incomplete"
-        net = re.search(r"on (.*?) ", r).group(1)
+        try:
+            net = re.search(r"on (.*?) ", r).group(1)
+        except AttributeError:
+            net = "unknown"
         device = {
             "ip": ip,
             "mac": mac,
